@@ -7,7 +7,6 @@ from io import BytesIO
 from urllib.parse import quote
 from urllib.request import urlopen
 from xml.dom import minidom
-from pma_python import pma
 
 import requests
 
@@ -15,7 +14,7 @@ __version__ = pma.__version__
 
 def set_debug_flag(flag):
 	"""
-	Determine whether Core module runs in debugging mode or not.
+	Determine whether pma_python runs in debugging mode or not.
 	When in debugging mode (flag = true), extra output is produced when certain conditions in the code are not met
 	"""
 	pma._pma_set_debug_flag(flag)
@@ -31,7 +30,7 @@ def _pma_admin_url(sessionID = None):
 
 def _pma_check_for_pma_start(method = "", url = None, session = None):
 	if (core._pma_pmacoreliteSessionID == session):
-		raise Exception("PMA.start doesn't support", methodName);
+		raise Exception("PMA.start doesn't support", method);
 	elif (url == core._pma_pmacoreliteURL):
 		if core.is_lite():
 			raise ValueError ("PMA.core.lite found running, but doesn't support an administrative back-end")
@@ -94,10 +93,54 @@ def add_user(admSessionID, login, firstName, lastName, email, pwd, canAnnotate =
 			"Password": pwd,
 			"Email": email,
 			"Administrator": isAdmin,
-			"CanAnnotate": canAnnotate
+			"CanAnnotate": canAnnotate,
+			"Suspended": isSuspended
 		} 
 	}
 	url = _pma_admin_url(admSessionID) + "CreateUser"
 	print(url)
 	createUserReponse = requests.post(url, json=createUserParams)
 	return createUserReponse.text
+	
+def create_amazons3_mounting_point(accessKey, secretKey, path, instanceId, chunkSize = 1048576, serviceUrl = None): 
+	"""
+	create an Amazon S3 mounting point. A list of these is to be used to supply method create_root_directory()
+	"""
+	createAmazonS3MountingPointParams = {
+		"AccessKey": accessKey,
+		"SecretKey": secretKey,
+		"ChunkSize": chunkSize,
+		"ServiceUrl": serviceUrl,
+		"Path": path,
+		"InstanceId": instanceId	
+	}
+	return createAmazonS3MountingPointParams
+
+def create_filesystem_mounting_point(username, password, domainName, path, instanceId): 
+	"""
+	create an FileSystem mounting point. A list of these is to be used to supply method create_root_directory()
+	"""
+	createFileSystemMountingPointParams = {
+		"Username": username,
+		"Password": password,
+		"DomainName": domainName,
+		"Path": path,
+		"InstanceId": instanceId	
+	}
+	return createFileSystemMountingPointParams
+	
+def	create_root_directory(admSessionID, alias, AmazonS3MountingPoints = None, FileSystemMountingPoints = None, description = "Root dir created through pma_python", isPublic = False, isOffline = False):
+	createRootDirectoryParams = {
+		"sessionID": admSessionID,
+		"rootDirectory": {
+			"Alias": alias,
+			"Description": description,
+			"Offline": isPublic,
+			"Public": isOffline,
+			"AmazonS3MountingPoints": AmazonS3MountingPoints,
+			"FileSystemMountingPoints": FileSystemMountingPoints
+		}
+	}
+	url = _pma_admin_url(admSessionID) + "CreateRootDirectory"
+	createRootDirectoryReponse = requests.post(url, json=createRootDirectoryParams)
+	return createRootDirectoryReponse.text
